--Arcaea-Technika v1.0
--Explosions and judgeline design stolen from Arcaea
--Note design stolen from DJMax TECHNIKA

local Noteskin = ... or {};
local button = Var "Button"

Noteskin.ButtonRedirs = {
	--Column layout for dance(4k/6k/8k)

	--Order:
	--4k: Left,Down,Up,Right
	--6k: Left,UpLeft,Down,Up,UpRight,Right
	--8k: Left,Down,Up,Right,Left,Down,Up,Right
	Left		= "Outer";
	UpLeft		= "Inner";
	Down		= "Inner";
	Up			= "Inner";
	UpRight		= "Inner";
	Right		= "Outer";
};

--Element redirects
Noteskin.ElementRedirs = {
	--Redirect dim explosion
	["Tap Explosion Dim"] = "Tap Explosion Bright";

	--Instead of separate hold heads and tails, use the tap note graphics.
	["Hold Head Active"] 	= "Tap Note";
	["Hold Head Inactive"] 	= "Tap Note";
	["Roll Head Active"] 	= "Roll Note";
	["Roll Head Inactive"] 	= "Roll Note";

	--Redirect hold elements
	["Hold TopCap Active"]		= "Hold Body";
	["Hold TopCap Inactive"]	= "Hold Body";

	--Redirect roll elements
	["Roll TopCap Active"]		= "Roll Body";
	["Roll TopCap Inactive"]	= "Roll Body";
	["Roll Explosion"]			= "Hold Explosion";
};

--Invisible elements
Noteskin.Hide = {
	["Tap Fake"] 				= true;
	["Tap Lift"] 				= true;
	["Hold Tail Active"] 		= true;
	["Hold Tail Inactive"] 		= true;
	["Roll Tail Active"] 		= true;
	["Roll Tail Inactive"] 		= true;
};

--Rotations. Everything is 0 because the textures aren't directional
Noteskin.BaseRotX = {
	Left	= 0;
	UpLeft	= 0;
	Up		= 0;
	Down	= 0;
	UpRight	= 0;
	Right	= 0;
};
Noteskin.BaseRotY = {
	Left	= 0;
	UpLeft	= 0;
	Up		= 0;
	Down	= 0;
	UpRight	= 0;
	Right	= 0;
};

local function NoteskinLoader()
	local Button = Var "Button"
	local Element = Var "Element"

	if Noteskin.Hide[Element] then
		--Return a blank element. If SpriteOnly is set, we need to return a
		--sprite; otherwise just return a dummy actor.
		local t;
		if Var "SpriteOnly" then
			t = LoadActor( "_blank" );
		else
			t = Def.Actor {};
		end
		return t .. {
			InitCommand = function(self)
    			self:visible(false)
  			end
		};
	end;


	--Load element and button, using redirs
	local LoadElement = Noteskin.ElementRedirs[Element]
	if not LoadElement then
		LoadElement = Element;
	end;

	local LoadButton = Noteskin.ButtonRedirs[Button]
	if not LoadButton then
		LoadButton = Button;
	end;

	--Get path to thing
	local sPath = NOTESKIN:GetPath( LoadButton, LoadElement );

	--Make actor
	local t = LoadActor( sPath );

	--Apply rotation
	t.BaseRotationX=Noteskin.BaseRotX[sButton]
	t.BaseRotationY=Noteskin.BaseRotY[sButton]
	
	return t;
end

Noteskin.Load = NoteskinLoader;
Noteskin.CommonLoad = NoteskinLoader;
return Noteskin;